@@ -10,6 +10,7 @@ OC.L10N.register(
     "Open »%s«" : "Digeriñ  »%s«",
     "Cheers!" : "A galon !",
     "Upcoming events" : "Darvoudoù da zont",
+    "Confirm" : "Kadarnañ",
     "Calendar" : "Deiziataer",
     "A Calendar app for Nextcloud" : "Un arload Deiziataerioù evit Nextcloud",
     "Previous day" : "Deizioù kent",
@@ -23,6 +24,9 @@ OC.L10N.register(
     "Week" : "Sizhun",
     "Month" : "Miz",
     "List" : "Roll",
+    "Preview" : "Ragwell",
+    "Copy link" : "Kopiañ al liamm",
+    "Edit" : "Cheñch",
     "Delete" : "Dilemel",
     "Untitled calendar" : "Deiziataer hep titl",
     "Edit name" : "Embann an anv",
@@ -75,6 +79,10 @@ OC.L10N.register(
     "Creating subscription …" : "Krouiñ ur goumanant ...",
     "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
+    "Name" : "Anv",
+    "Deleted" : "Lamet",
+    "Restore" : "Adkrouiñ",
+    "Delete permanently" : "Lamet da viken",
     "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
     "Import calendars" : "Emporzhiañ deizataerioù",
     "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
@@ -86,18 +94,25 @@ OC.L10N.register(
     "{filename} could not be parsed" : "{filename} na c'hell ket bezhañ dielfennet",
     "No valid files found, aborting import" : "Restr mat kavet ebet, arrestet e vez an emporzhiañ",
     "Import partially failed. Imported {accepted} out of {total}." : "Emporzhiañ damc'hwitet. Emporzhiet {accepted} diwar {total}.",
+    "List view" : "Gwelidik listenn",
     "Actions" : "Oberoù",
     "Location" : "Lec'hiadur",
     "Description" : "Deskrivadur",
+    "Add" : "Ouzhpennañ",
     "Monday" : "Lun",
     "Save" : "Enrollañ",
     "Update" : "Hizivaat",
+    "Your email address" : "O chom-lec'h postel",
     "Notification" : "Kemenadenn",
     "Email" : "Postel",
+    "Available" : "Vak",
+    "Not available" : "Divak",
     "Free" : "Digoust",
     "Busy" : "O labourat",
     "Unknown" : "Dianv",
+    "Accept" : "Asantiñ",
     "Tentative" : "Taol-esae",
+    "Send email" : "Kas postel",
     "never" : "james",
     "after" : "goude",
     "first" : "kentañ",
@@ -119,9 +134,11 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
     "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
     "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
+    "Next" : "Da heul",
     "%n more" : "%n ouzhpenn",
     "No events to display" : "Darvoud ebet da ziskouez",
     "No events" : "Darvoud ebet",
+    "Other" : "All",
     "When shared show" : "Diskouez pa vez lodet",
     "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
     "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
@@ -147,6 +164,7 @@ OC.L10N.register(
     "Relaxing" : "Distanañ",
     "Relax" : "Distanañ",
     "Presentation" : "Kinnigadenn",
+    "Talk" : "Komz",
     "Camping" : "Kampiñ",
     "Camp" : "Kamp",
     "Movie" : "Film",
@@ -221,6 +239,7 @@ OC.L10N.register(
     "Party" : "Fest",
     "Celebration" : "Lid",
     "Celebrate" : "Lid",
+    "Birthday" : "Deiz-ha-bloaz",
     "Shopping" : "Staliaoua",
     "Skate" : "Plankenn-ruilh",
     "Skateboard" : "Plankenn-ruilh",
