@@ -30,6 +30,9 @@ OC.L10N.register(
     "Week" : "Setmana",
     "Month" : "Mes",
     "List" : "Llista",
+    "Preview" : "Previsualitza",
+    "Copy link" : "Copia l'enllaç",
+    "Edit" : "Edita",
     "Delete" : "Suprimeix",
     "Untitled calendar" : "Calendari sense títol",
     "Edit name" : "Edita el nom",
@@ -37,6 +40,7 @@ OC.L10N.register(
     "Edit color" : "Edita el color",
     "Saving color …" : "S'està desant el color...",
     "Copy private link" : "Copia l'enllaç privat",
+    "Export" : "Exporta",
     "Unshare from me" : "Deixa de compartir",
     "An error occurred, unable to change visibility of the calendar." : "S'ha produït un error. No s'ha canviat la visibilitat del calendari.",
     "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
@@ -84,6 +88,10 @@ OC.L10N.register(
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
     "Trash bin" : "Paperera",
     "Name" : "Nom",
+    "Deleted" : "S'ha suprimit",
+    "Restore" : "Restaura",
+    "Delete permanently" : "Suprimeix de manera permanent",
+    "Empty trash bin" : "Buida la paperera",
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
     "Import calendars" : "Importar calendaris",
     "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
@@ -107,6 +115,7 @@ OC.L10N.register(
     "Day view" : "Vista de dia",
     "Week view" : "Vista de setmana",
     "Month view" : "Vista de mes",
+    "List view" : "Vista de llista",
     "Actions" : "Accions",
     "Create event" : "Crea un esdeveniment",
     "Show shortcuts" : "Mostra les dreceres",
@@ -120,6 +129,7 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
     "Settings & import" : "Paràmetres i importació",
+    "No reminder" : "Sense recordatoris",
     "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
     "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
@@ -133,6 +143,8 @@ OC.L10N.register(
     "Description" : "Descripció",
     "Visibility" : "Visibilitat",
     "Duration" : "Durada",
+    "to" : "a",
+    "Add" : "Afegeix",
     "Monday" : "Dilluns",
     "Tuesday" : "Dimarts",
     "Wednesday" : "Dimecres",
@@ -142,6 +154,7 @@ OC.L10N.register(
     "Sunday" : "Diumenge",
     "Save" : "Desa",
     "Update" : "Actualitza",
+    "Your email address" : "La vostra adreça de correu",
     "before at" : "abans a les",
     "Notification" : "Notificació",
     "Email" : "Correu",
@@ -160,6 +173,8 @@ OC.L10N.register(
     "_hour_::_hours_" : ["hora","hores"],
     "_day_::_days_" : ["dia","dies"],
     "_week_::_weeks_" : ["setmana","setmanes"],
+    "Available" : "Disponible",
+    "Not available" : "No disponible",
     "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
     "Free" : "Disponible",
     "Busy (tentative)" : "Ocupat (provisional)",
@@ -174,6 +189,7 @@ OC.L10N.register(
     "No attendees yet" : "Encara no hi ha cap participant",
     "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala del Talk a la descripció de l'event.",
     "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
+    "Send email" : "Enviar correu",
     "Chairperson" : "Organització",
     "Required participant" : "Participació obligatòria",
     "Optional participant" : "Participació opcional",
@@ -211,6 +227,7 @@ OC.L10N.register(
     "weekend day" : "dia de cap de setmana",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest event no es del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
     "Suggestions" : "Suggeriments",
+    "available" : "disponible",
     "More" : "Més",
     "Update this occurrence" : "Actualitza aquesta ocurrència",
     "Update this and all future" : "Actualitza aquesta i les futures",
@@ -228,6 +245,7 @@ OC.L10N.register(
     "Please enter a valid date" : "Indiqueu una data vàlida",
     "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
     "Global" : "Global",
+    "Time:" : "Hora:",
     "Personal" : "Personal",
     "No more events today" : "Avui no hi ha més esdeveniments",
     "No upcoming events" : "No hi ha propers esdeveniments",
@@ -245,7 +263,6 @@ OC.L10N.register(
     "Close" : "Tanca",
     "Show more details" : "Mostra més detalls",
     "Subscribe to {name}" : "Subscriure a {name}",
-    "Download {name}" : "Baixa {name}",
     "Anniversary" : "Commemoració",
     "Appointment" : "Cita",
     "Business" : "Negocis",
@@ -292,6 +309,8 @@ OC.L10N.register(
     "Untitled event" : "Esdeveniment sense títol",
     "Untitled task" : "Tasca sense títol",
     "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
+    "Prev" : "Anterior",
+    "Next" : "Següent",
     "Year" : "Any",
     "W" : "S",
     "%n more" : "%n més",
@@ -302,6 +321,7 @@ OC.L10N.register(
     "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
     "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
     "Meeting room" : "Sala de reunions",
+    "Other" : "Altres",
     "When shared show" : "Mostrar a compartits",
     "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
     "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
@@ -326,7 +346,9 @@ OC.L10N.register(
     "Meditation" : "Meditació",
     "Relaxing" : "Relax",
     "Relax" : "Relax",
+    "Commuting" : "Trajecte",
     "Presentation" : "Presentació",
+    "Talk" : "Parla",
     "Camping" : "Acampada",
     "Camp" : "Campament",
     "Garden" : "Jardí",
@@ -367,6 +389,7 @@ OC.L10N.register(
     "Doctor" : "Doctor",
     "Health" : "Salut",
     "Dentist" : "Dentista",
+    "Hospital" : "Hospital",
     "Interview" : "Entrevista",
     "Training" : "Entrenament",
     "Practice" : "Pràctica",
@@ -409,6 +432,7 @@ OC.L10N.register(
     "Party" : "Festa",
     "Celebration" : "Celebració",
     "Celebrate" : "Celebrar",
+    "Birthday" : "Aniversari",
     "Shopping" : "Anar de compres",
     "Skate" : "Patinar",
     "Skateboard" : "Skateboard",
