@@ -8,23 +8,41 @@ OC.L10N.register(
     "Cheers!" : "Hwyl!",
     "Calendar" : "Calendr",
     "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
+    "New event" : "Digwyddiad newydd",
     "Today" : "Heddiw",
     "Day" : "Diwrnod",
     "Week" : "Wythnos",
     "Month" : "Mis",
+    "Preview" : "Rhagolwg",
+    "Copy link" : "Copïo dolen",
+    "Edit" : "Golygu",
     "Delete" : "Dileu",
+    "Export" : "Allforio",
     "Share link" : "Rhannu dolen",
     "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
     "No users or groups" : "Dim defnyddwyr na grwpiau",
     "can edit" : "yn gallu golygu",
     "New calendar" : "Calendr newydd",
+    "Name" : "Enw",
+    "Deleted" : "Wedi dileu",
+    "Restore" : "Adfer",
+    "Delete permanently" : "Dileu'n barhaol",
     "Cancel" : "Diddymu",
+    "List view" : "Golwg rhestr",
     "Actions" : "Gweithredoedd",
     "Show week numbers" : "Dangos rhifau wythnosau",
     "Settings & import" : "Gosodiadau a mewnforio",
     "Location" : "Lleoliad",
     "Description" : "Disgrifiad",
+    "to" : "at",
+    "Add" : "Ychwanegu",
     "Monday" : "Llun",
+    "Tuesday" : "Mawrth",
+    "Wednesday" : "Mercher",
+    "Thursday" : "Iau",
+    "Friday" : "Gwener",
+    "Saturday" : "Sadwrn",
+    "Sunday" : "Sul",
     "Save" : "Cadw",
     "Update" : "Diweddaru",
     "Email" : "E-bost",
@@ -41,10 +59,13 @@ OC.L10N.register(
     "Close" : "Cau",
     "Anniversary" : "Dathliad",
     "Week {number} of {year}" : "Wythnos {number} o {year}",
+    "Next" : "Nesaf",
+    "Other" : "Arall",
     "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
     "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
     "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
     "Confirmed" : "Cadarnhawyd",
-    "Mail" : "E-bost"
+    "Mail" : "E-bost",
+    "Birthday" : "Pen-blwydd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
