@@ -9,6 +9,11 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
     "Open »%s«" : "Åbn »%s«",
     "Cheers!" : "Hav en fortsat god dag.",
+    "Appointments" : "Aftaler",
+    "Confirm" : "Bekræft",
+    "Date:" : "Dato:",
+    "Where:" : "Hvor:",
+    "Description:" : "Beskrivelse:",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
     "Previous day" : "Forrige dag",
@@ -17,10 +22,15 @@ OC.L10N.register(
     "Next day" : "Næste dag",
     "Next week" : "Næste uge",
     "Next month" : "Næste måned",
+    "New event" : "Opret begivenhed",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Uge",
     "Month" : "Måned",
+    "List" : "Liste",
+    "Preview" : "Forhåndsvisning",
+    "Copy link" : "Kopiér link",
+    "Edit" : "Rediger",
     "Delete" : "Slet",
     "Untitled calendar" : "Unanvngiven kalender",
     "Edit name" : "Rediger navn",
@@ -28,6 +38,7 @@ OC.L10N.register(
     "Edit color" : "Rediger farve",
     "Saving color …" : "Gemmer farve…",
     "Copy private link" : "Kopier privat link",
+    "Export" : "Eksportér",
     "Unshare from me" : "Fjern deling fra mig",
     "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
     "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
@@ -62,24 +73,43 @@ OC.L10N.register(
     "Creating calendar …" : "Opretter kalender…",
     "New calendar with task list" : "Ny kalender med opgaveliste",
     "Creating subscription …" : "Opretter abonnement…",
+    "Name" : "Navn",
+    "Deleted" : "Slettet",
+    "Restore" : "Gendan",
+    "Delete permanently" : "Slet permanent",
+    "Empty trash bin" : "Tom papirkurv",
     "Import calendars" : "Importer kalendere",
     "Filename" : "Filnavn",
     "Cancel" : "Annullér",
     "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
     "Automatic" : "Automatisk",
     "or" : "eller",
+    "List view" : "Vis som liste",
     "Actions" : "Handlinger",
     "Enable birthday calendar" : "Slå fødselsdagskalender til",
     "Enable simplified editor" : "Slå simpel editor til",
     "Show weekends" : "Vis weekender",
     "Show week numbers" : "Vis ugenummer ",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
+    "Show keyboard shortcuts" : "Vis tastaturgenveje",
     "Settings & import" : "Indstillinger & importer",
+    "No reminder" : "Ingen påmindelse",
     "Location" : "Sted",
     "Description" : "Beskrivelse",
+    "Visibility" : "Synlighed",
+    "Duration" : "Varighed",
+    "to" : "til",
+    "Add" : "Tilføj",
     "Monday" : "Mandag",
+    "Tuesday" : "Tirsdag",
+    "Wednesday" : "Onsdag",
+    "Thursday" : "Torsdag",
+    "Friday" : "Fredag",
+    "Saturday" : "Lørdag",
+    "Sunday" : "Søndag",
     "Save" : "Gem",
     "Update" : "Opdatér",
+    "Your email address" : "Din email adresse",
     "Notification" : "Notifikation",
     "Email" : "E-mail",
     "_second_::_seconds_" : ["sekund","sekunder"],
@@ -87,10 +117,14 @@ OC.L10N.register(
     "_hour_::_hours_" : ["time","timer"],
     "_day_::_days_" : ["dag","dage"],
     "_week_::_weeks_" : ["uge","uger"],
+    "Available" : "Tilgængelig",
     "Busy" : "Optaget",
     "Unknown" : "Ukendt",
+    "Accept" : "Accepter",
+    "Decline" : "Afvis",
     "Tentative" : "Foreløbig",
     "Create Talk room for this event" : "Opret Snak rum for denne begivenhed",
+    "Send email" : "Send e-mail",
     "Event title" : "Titel",
     "All day" : "Hele dagen",
     "from {startDate}" : "fra {startDate}",
@@ -110,27 +144,38 @@ OC.L10N.register(
     "_year_::_years_" : ["år","år"],
     "weekday" : "hverdag",
     "weekend day" : "weekenddag",
+    "available" : "tilgængelig",
     "More" : "Mere",
+    "Pick a date" : "Vælg en dato",
     "Global" : "Global",
+    "Time:" : "Tid:",
     "Personal" : "Personlig",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
+    "Resources" : "Resourcer",
     "Close" : "Luk",
     "Anniversary" : "Årsdag",
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Daily" : "Dagligt",
     "Weekly" : "Ugentligt",
     "Untitled event" : "Unavngiven begivenhed",
+    "Next" : "Næste",
+    "Year" : "År",
+    "Other" : "Andet",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
     "When shared hide this event" : "Når delt, skjul denne begivenhed",
     "Status" : "Status",
     "Confirmed" : "Bekræftet",
+    "Canceled" : "Annulleret",
     "Categories" : "Kategorier",
     "Presentation" : "Præsentation",
+    "Talk" : "Snak",
     "Movie" : "Film",
     "Review" : "Gennemse",
     "Office" : "Kontor",
-    "Mail" : "Mail"
+    "Mail" : "Mail",
+    "Birthday" : "Fødselsdag",
+    "User not found" : "Bruger ikke fundet"
 },
 "nplurals=2; plural=(n != 1);");
