@@ -6,14 +6,23 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Ni volis sciigi vin, ke %s publikigis la kalendaron „%s“.",
     "Open »%s«" : "Malfermi „%s“",
     "Cheers!" : "Ĝis!",
+    "Confirm" : "Konfirmi",
+    "Date:" : "Dato:",
+    "Where:" : "Kie:",
+    "Description:" : "Priskribo:",
     "Calendar" : "Kalendaro",
     "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
+    "New event" : "Nova okazaĵo",
     "Today" : "Hodiaŭ",
     "Day" : "Tago",
     "Week" : "Semajno",
     "Month" : "Monato",
+    "Preview" : "Antaŭvidi",
+    "Copy link" : "Kopii ligilon",
+    "Edit" : "Modifi",
     "Delete" : "Forigi",
     "Copy private link" : "Kopii privatan ligilon",
+    "Export" : "Eksporti",
     "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
     "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
     "Share link" : "Kunhavigi ligilon",
@@ -22,21 +31,39 @@ OC.L10N.register(
     "No users or groups" : "Neniu uzanto aŭ grupo",
     "can edit" : "povas redakti",
     "New calendar" : "Nova kalendaro",
+    "Name" : "Nomo",
+    "Deleted" : "Forigita",
+    "Restore" : "Restaŭri",
+    "Delete permanently" : "Forigi por ĉiam",
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
+    "List view" : "Lista vido",
     "Actions" : "Agoj",
     "Show week numbers" : "Montri numerojn de semajno",
     "Settings & import" : "Agordoj kaj enporto",
     "Location" : "Loko",
     "Description" : "Priskribo",
+    "to" : "al",
+    "Add" : "Aldoni",
     "Monday" : "lundo",
+    "Tuesday" : "mardo",
+    "Wednesday" : "merkredo",
+    "Thursday" : "ĵaŭdo",
+    "Friday" : "vendredo",
+    "Saturday" : "sabato",
+    "Sunday" : "dimanĉo",
     "Save" : "Konservi",
     "Update" : "Ĝisdatigi",
+    "Your email address" : "Via retpoŝta adreso",
     "Email" : "Retpoŝto",
+    "Available" : "Disponeblaj",
     "Busy" : "Okupita",
     "Unknown" : "Nekonata",
+    "Accept" : "Akcepti",
+    "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
+    "Send email" : "Sendi retpoŝtmesaĝon",
     "All day" : "Tuttage",
     "Repeat" : "Ripeti",
     "never" : "neniam",
@@ -49,12 +76,15 @@ OC.L10N.register(
     "[Yesterday]" : "[Hieraŭ]",
     "Details" : "Detaloj",
     "Attendees" : "Ĉeestontoj",
+    "Resources" : "Rimedoj",
     "Close" : "Fermi",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
     "Untitled event" : "Sentitola okazaĵo",
+    "Next" : "Sekva",
+    "Other" : "Alia",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
     "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
@@ -63,6 +93,9 @@ OC.L10N.register(
     "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
-    "Mail" : "Retpoŝtilo"
+    "Talk" : "Paroli",
+    "Mail" : "Retpoŝtilo",
+    "Birthday" : "Naskiĝotago",
+    "User not found" : "Netrovita uzanto"
 },
 "nplurals=2; plural=(n != 1);");
