@@ -6,6 +6,7 @@ OC.L10N.register(
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
     "Upcoming events" : "Próximos eventos",
+    "Confirm" : "Confirmar",
     "Calendar" : "Calendario",
     "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
     "Previous day" : "Día previo",
@@ -14,14 +15,19 @@ OC.L10N.register(
     "Next day" : "Proximo día",
     "Next week" : "Proxima semana",
     "Next month" : "Proximo mes",
+    "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
     "Month" : "Mes",
     "List" : "Lista",
+    "Preview" : "Vista previa",
+    "Copy link" : "Copiar enlace",
+    "Edit" : "Editar",
     "Delete" : "Borrar",
     "Edit name" : "Editar nombre",
     "Edit color" : "Editar color",
+    "Export" : "Exportar",
     "Share link" : "Compartir link",
     "Copy public link" : "Copiar link publico",
     "Copied link" : "Link copiado",
@@ -31,35 +37,58 @@ OC.L10N.register(
     "can edit" : "puede editar",
     "New calendar" : "Nuevo calendario",
     "New calendar with task list" : "Nuevo calendario con listado de tareas",
+    "Name" : "Nombre",
+    "Deleted" : "Eliminado",
+    "Restore" : "Restaurar",
+    "Delete permanently" : "Borrar permanentemente",
     "Filename" : "Nombre de archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
     "Settings & import" : "Configuraciones & importar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "to" : "para",
+    "Add" : "Añadir",
     "Monday" : "Lunes",
+    "Tuesday" : "Martes",
+    "Wednesday" : "Miércoles",
+    "Thursday" : "Jueves",
+    "Friday" : "Viernes",
+    "Saturday" : "Sábado",
+    "Sunday" : "Domingo",
     "Save" : "Guardar",
     "Update" : "Actualizar",
+    "Your email address" : "Su dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "Available" : "Disponible",
     "Unknown" : "Desconocido",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Send email" : "Enviar correo electrónico",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
+    "available" : "disponible",
     "More" : "Más",
     "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
+    "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
+    "Prev" : "Prev",
+    "Next" : "Siguiente",
+    "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
@@ -67,6 +96,7 @@ OC.L10N.register(
     "Confirmed" : "Confirmado",
     "Categories" : "Categoría",
     "Movie" : "Película",
-    "Mail" : "Correo Electrónico"
+    "Mail" : "Correo Electrónico",
+    "Birthday" : "Fecha de nacimiento"
 },
 "nplurals=2; plural=(n != 1);");
