@@ -6,6 +6,9 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
     "Open »%s«" : "Ava »%s«",
     "Cheers!" : "Tervist!",
+    "Confirm" : "Kinnita",
+    "Where:" : "Kus:",
+    "Description:" : "Kirjeldus:",
     "Calendar" : "Kalender",
     "Previous day" : "Eelmine päev",
     "Previous week" : "Eelmine nädal",
@@ -13,10 +16,14 @@ OC.L10N.register(
     "Next day" : "Järgmine päev",
     "Next week" : "Järgmine nädal",
     "Next month" : "Järgmine kuu",
+    "New event" : "Uus sündmus",
     "Today" : "Täna",
     "Day" : "Päev",
     "Week" : "Nädal",
     "Month" : "Kuu",
+    "Preview" : "Eelvaade",
+    "Copy link" : "Kopeeri link",
+    "Edit" : "Redigeeri",
     "Delete" : "Kustuta",
     "Untitled calendar" : "Nimetu kalender",
     "Edit name" : "Muuda nime",
@@ -24,6 +31,7 @@ OC.L10N.register(
     "Edit color" : "Muuda värvi",
     "Saving color …" : "Salvestan värvi ...",
     "Copy private link" : "Kopeeri privaatne link",
+    "Export" : "Ekspordi",
     "Share link" : "Jaga link",
     "Publish calendar" : "Avalda kalender",
     "Copy public link" : "Kopeeri avalik link",
@@ -34,22 +42,39 @@ OC.L10N.register(
     "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
     "+ New calendar" : "+ Uus kalender",
     "New calendar" : "Uus kalender",
+    "Name" : "Nimi",
+    "Deleted" : "Kustutatud",
+    "Restore" : "Taasta",
+    "Delete permanently" : "Kustuta jäädavalt",
     "Import calendars" : "Impordi kalendrid",
     "Filename" : "Faili nimi",
     "Cancel" : "Loobu",
     "Automatic" : "Automaatne",
+    "List view" : "Nimekirjavaade",
     "Actions" : "Tegevused",
     "Show week numbers" : "Näita nädalanumberid",
     "Settings & import" : "Sätted & importimine",
     "Location" : "Asukoht",
     "Description" : "Kirjeldus",
+    "to" : "saaja",
+    "Add" : "Lisa",
     "Monday" : "Esmaspäev",
+    "Tuesday" : "Teisipäev",
+    "Wednesday" : "Kolmapäev",
+    "Thursday" : "Neljapäev",
+    "Friday" : "Reede",
+    "Saturday" : "Laupäev",
+    "Sunday" : "Pühapäev",
     "Save" : "Salvesta",
     "Update" : "Uuenda",
+    "Your email address" : "Sinu e-posti aadress",
     "Email" : "Epost",
     "On date" : "Kuupäeval",
     "Unknown" : "Teadmata",
+    "Accept" : "Nõustu",
+    "Decline" : "Keeldu",
     "Tentative" : "Esialgne",
+    "Send email" : "Saada kiri",
     "All day" : "Kogu päev",
     "Repeat" : "Korda",
     "never" : "mitte kunagi",
@@ -59,6 +84,7 @@ OC.L10N.register(
     "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
     "Attendees" : "Osalejad",
+    "Resources" : "Ressursid",
     "Close" : "Sulge",
     "Anniversary" : "Aastapäev",
     "Appointment" : "Kohtumine",
@@ -69,6 +95,8 @@ OC.L10N.register(
     "Weekly" : "Iga nädal",
     "Monthly" : "Igakuine",
     "Yearly" : "Igaastane",
+    "Next" : "Järgmine",
+    "Other" : "Muu",
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
@@ -76,6 +104,7 @@ OC.L10N.register(
     "Confirmed" : "Kinnitatud",
     "Categories" : "Kategooriad",
     "Presentation" : "Esitlus",
+    "Talk" : "Talk",
     "Camping" : "Telkimine",
     "Camp" : "Laager",
     "Movie" : "Film",
@@ -129,10 +158,12 @@ OC.L10N.register(
     "Party" : "Pidu",
     "Celebration" : "Tähistamine",
     "Celebrate" : "Tähista",
+    "Birthday" : "Sünnipäev",
     "Skate" : "Uisutamine",
     "Skateboard" : "Rula",
     "Wine tasting" : "Veini degusteerimine",
     "Golf" : "Golf",
-    "Dinner" : "Õhtusöök"
+    "Dinner" : "Õhtusöök",
+    "User not found" : "Kasutajat ei leitud"
 },
 "nplurals=2; plural=(n != 1);");
