@@ -3,18 +3,33 @@ OC.L10N.register(
     {
     "Cheers!" : "Չը՛խկ",
     "Calendar" : "Օրացույց",
+    "New event" : "Նոր իրադարձություն",
     "Today" : "Այսօր",
     "Day" : "Օր",
     "Week" : "Շաբաթ",
     "Month" : "Ամիս",
+    "Copy link" : "Պատճենել հղումը",
+    "Edit" : "մշակել",
     "Delete" : "Ջնջել",
+    "Export" : "Արտահանում",
     "Share link" : "Կիսվել հղմամբ",
     "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
     "can edit" : "կարող է խմբագրել",
+    "Name" : "Անուն",
+    "Deleted" : "Ջնջված",
+    "Restore" : "Վերականգնել",
+    "Delete permanently" : "Ջնջել ընդմիշտ",
     "Cancel" : "Չեղարկել",
     "Location" : "Տեղակայություն",
     "Description" : "Նկարագրություն",
+    "Add" : "Ավելացնել",
     "Monday" : "Երկուշաբթի",
+    "Tuesday" : "Երեքշաբթի",
+    "Wednesday" : "Չորեքշաբթի",
+    "Thursday" : "Հինգշաբթի",
+    "Friday" : "Ուրբաթ",
+    "Saturday" : "Շաբաթ",
+    "Sunday" : "Կիրակի",
     "Save" : "Պահպանել",
     "Update" : "Թարմացնել",
     "Email" : "Էլ․փոստ",
@@ -28,7 +43,10 @@ OC.L10N.register(
     "Details" : "Մանրամասներ",
     "Attendees" : "Մասնակիցներ",
     "Close" : "Փակել",
+    "Next" : "Հաջորդ",
+    "Other" : "Այլ",
     "Confirmed" : "Հաստատված",
-    "Mail" : "Փոստ"
+    "Mail" : "Փոստ",
+    "Birthday" : "Ծննդյան օր"
 },
 "nplurals=2; plural=(n != 1);");
