@@ -8,6 +8,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
+    "Confirm" : "Konfirmasi",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
     "Previous day" : "Hari sebelum",
@@ -20,6 +21,9 @@ OC.L10N.register(
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
+    "Preview" : "Pratinjau",
+    "Copy link" : "Salin tautan",
+    "Edit" : "Sunting",
     "Delete" : "Hapus",
     "Untitled calendar" : "Kalender tanpa judul",
     "Edit name" : "Edit nama",
@@ -27,6 +31,7 @@ OC.L10N.register(
     "Edit color" : "Edit warna",
     "Saving color …" : "Menyimpan warna …",
     "Copy private link" : "Salin tautan privat",
+    "Export" : "Ekspor",
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
@@ -70,6 +75,11 @@ OC.L10N.register(
     "Creating subscription …" : "Membuat langganan …",
     "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
+    "Name" : "Nama",
+    "Deleted" : "Dihapus",
+    "Restore" : "Pulihkan",
+    "Delete permanently" : "Hapus secara permanen",
+    "Empty trash bin" : "Kosongkan tempat sampah",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -88,6 +98,7 @@ OC.L10N.register(
     "Day view" : "Tampilan hari",
     "Week view" : "Tampilan minggu",
     "Month view" : "Tampilan bulan",
+    "List view" : "Tampilan lis",
     "Actions" : "Tindakan",
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
@@ -105,9 +116,18 @@ OC.L10N.register(
     "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
+    "to" : "untuk",
+    "Add" : "Masukkan",
     "Monday" : "Senin",
+    "Tuesday" : "Selasa",
+    "Wednesday" : "Rabu",
+    "Thursday" : "Kamis",
+    "Friday" : "Jumat",
+    "Saturday" : "Sabtu",
+    "Sunday" : "Minggu",
     "Save" : "Simpan",
     "Update" : "Perbarui",
+    "Your email address" : "Alamat surel Anda",
     "Notification" : "Notifikasi",
     "Email" : "Surel",
     "Audio notification" : "Notifikasi audio",
@@ -131,12 +151,15 @@ OC.L10N.register(
     "Busy" : "Sibuk",
     "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
+    "Accept" : "Terima",
+    "Decline" : "Tolak",
     "Tentative" : "Tentatif",
     "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
     "Show busy times" : "Tampilkan waktu sibuk",
     "No attendees yet" : "Belum ada peserta",
     "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
     "Error creating Talk room" : "Galat membuat ruangan Talk",
+    "Send email" : "Kirim surel",
     "Required participant" : "Partisipan wajib",
     "Optional participant" : "Partisipan opsional",
     "Non-participant" : "Bukan partisipan",
@@ -179,7 +202,6 @@ OC.L10N.register(
     "Close" : "Tutup",
     "Show more details" : "Tampilkan detail lain",
     "Subscribe to {name}" : "Berlangganan ke {name}",
-    "Download {name}" : "Unduh {name}",
     "Anniversary" : "Hari jadi",
     "Appointment" : "Janji",
     "Business" : "Bisnis",
@@ -222,7 +244,9 @@ OC.L10N.register(
     "Untitled event" : "Acara tanpa judul",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
+    "Next" : "Berikutnya",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
+    "Other" : "Lainnya",
     "Add a location" : "Tambah lokasi",
     "Add a description" : "Tambah deskripsi",
     "Status" : "Status",
@@ -236,6 +260,9 @@ OC.L10N.register(
     "Add this as a new category" : "Tambah sebagai kategori baru",
     "Custom color" : "Warna khusus",
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
-    "Chat room for event" : "Ruang obrolan untuk acara"
+    "Chat room for event" : "Ruang obrolan untuk acara",
+    "Review" : "Tinjauan",
+    "Mail" : "Email",
+    "Birthday" : "Tanggal lahir"
 },
 "nplurals=1; plural=0;");
