@@ -9,6 +9,11 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Við vildum láta þig vita að %s gaf út dagatalið »%s«.",
     "Open »%s«" : "Opna »%s«",
     "Cheers!" : "Til hamingju!",
+    "Appointments" : "Stefnumót",
+    "Confirm" : "Staðfesta",
+    "Date:" : "Dagsetning:",
+    "Where:" : "Hvar:",
+    "Description:" : "Lýsing:",
     "Calendar" : "Dagatal",
     "A Calendar app for Nextcloud" : "Dagatalsforrit fyrir Nextcloud",
     "Previous day" : "Fyrri dagur",
@@ -17,11 +22,15 @@ OC.L10N.register(
     "Next day" : "Næsta dag",
     "Next week" : "Næsta viku",
     "Next month" : "Næsti mánuður",
+    "New event" : "Nýr atburður",
     "Today" : "Í dag",
     "Day" : "Dagur",
     "Week" : "Vika",
     "Month" : "Mánuður",
     "List" : "Listi",
+    "Preview" : "Forskoðun",
+    "Copy link" : "Afrita tengil",
+    "Edit" : "Breyta",
     "Delete" : "Eyða",
     "Untitled calendar" : "Ónefnt dagatal",
     "Edit name" : "Breyta heiti",
@@ -29,6 +38,7 @@ OC.L10N.register(
     "Edit color" : "Breyta lit",
     "Saving color …" : "Vista lit …",
     "Copy private link" : "Afrita einkatengil",
+    "Export" : "Flytja út",
     "Unshare from me" : "Hætta deilingu frá mér",
     "An error occurred, unable to change visibility of the calendar." : "Villa kom upp, gat ekki breytt sýnileika dagatalsins.",
     "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
@@ -74,6 +84,10 @@ OC.L10N.register(
     "Creating subscription …" : "Útbý áskrift …",
     "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
+    "Name" : "Heiti",
+    "Deleted" : "Eytt",
+    "Restore" : "Endurheimta",
+    "Delete permanently" : "Eyða varanlega",
     "Import calendars" : "Flytja inn dagatöl",
     "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
     "Filename" : "Skráarheiti",
@@ -95,6 +109,7 @@ OC.L10N.register(
     "Day view" : "Dagsyfirlit",
     "Week view" : "Vikuyfirlit",
     "Month view" : "Mánaðaryfirlit",
+    "List view" : "Listasýn",
     "Actions" : "Aðgerðir",
     "Create event" : "Búa til atburð",
     "Show shortcuts" : "Birta flýtileiðir",
@@ -111,9 +126,19 @@ OC.L10N.register(
     "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
     "Location" : "Staðsetning",
     "Description" : "Lýsing",
+    "Duration" : "Duration",
+    "to" : "til",
+    "Add" : "Bæta við",
     "Monday" : "Mánudagur",
+    "Tuesday" : "Þriðjudagur",
+    "Wednesday" : "Miðvikudagur",
+    "Thursday" : "Fimmtudagur",
+    "Friday" : "Föstudagur",
+    "Saturday" : "Laugardagur",
+    "Sunday" : "Sunnudagur",
     "Save" : "Vista",
     "Update" : "Uppfæra",
+    "Your email address" : "Netfangið þitt",
     "Notification" : "Tilkynning",
     "Email" : "Tölvupóstur",
     "Audio notification" : "Hljóðáminning",
@@ -130,15 +155,20 @@ OC.L10N.register(
     "_hour_::_hours_" : ["klukkustund","klukkustundir"],
     "_day_::_days_" : ["dagur","dagar"],
     "_week_::_weeks_" : ["vika","vikur"],
+    "Available" : "Tiltækt",
+    "Not available" : "Not available",
     "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
     "Free" : "Laus",
     "Busy (tentative)" : "Upptekinn (með fyrirvara)",
     "Busy" : "Upptekinn",
     "Out of office" : "Ekki á staðnum",
     "Unknown" : "Óþekkt",
+    "Accept" : "Samþykkja",
+    "Decline" : "Hafna",
     "Tentative" : "Með fyrirvara",
     "Show busy times" : "Sýna upptekinn tíma",
     "No attendees yet" : "Engir þáttakendur ennþá",
+    "Send email" : "Senda tölvupóst",
     "Chairperson" : "Fundarstjóri",
     "Required participant" : "Nauðsynlegur þáttakandi",
     "Optional participant" : "Aukaþáttakandi",
@@ -172,6 +202,7 @@ OC.L10N.register(
     "_year_::_years_" : ["ár","ár"],
     "weekday" : "vinnudagur",
     "weekend day" : "helgardagur",
+    "available" : "tiltækt",
     "More" : "Meira",
     "Update this occurrence" : "Uppfæra þetta tilviki",
     "Update this and all future" : "Uppfæra þetta og öll síðari",
@@ -193,10 +224,10 @@ OC.L10N.register(
     "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
     "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
+    "Resources" : "Tilföng",
     "Close" : "Loka",
     "Show more details" : "Sýna frekari upplýsingar",
     "Subscribe to {name}" : "Panta áskrift að {name}",
-    "Download {name}" : "Sækja {name}",
     "Anniversary" : "Afmæli",
     "Appointment" : "Stefnumót",
     "Business" : "Viðskipti",
@@ -224,7 +255,11 @@ OC.L10N.register(
     "Untitled event" : "Ónefndur atburður",
     "Untitled task" : "Ónefnt verkefni",
     "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
+    "Prev" : "Fyrra",
+    "Next" : "Næsta",
+    "Year" : "Ár",
     "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
+    "Other" : "Annað",
     "When shared show" : "Þegar er deilt, birta ",
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
@@ -249,7 +284,9 @@ OC.L10N.register(
     "Meditation" : "Hugleiðsla",
     "Relaxing" : "Afslöppun",
     "Relax" : "Afslöppun",
+    "Commuting" : "Á ferðinni",
     "Presentation" : "Kynning",
+    "Talk" : "Spjalla",
     "Camping" : "Tjaldútilega",
     "Camp" : "Tjaldstæði",
     "Movie" : "Kvikmynd",
@@ -286,6 +323,7 @@ OC.L10N.register(
     "Doctor" : "Læknir",
     "Health" : "Heilsa",
     "Dentist" : "Tannlæknir",
+    "Hospital" : "Sjúkrahús",
     "Interview" : "Viðtal",
     "Training" : "Þjálfun",
     "Practice" : "Æfingar",
@@ -324,12 +362,14 @@ OC.L10N.register(
     "Party" : "Partý",
     "Celebration" : "Hátíðahöld",
     "Celebrate" : "Fagna",
+    "Birthday" : "Afmælisdagur",
     "Shopping" : "Versla",
     "Skate" : "Skautar",
     "Skateboard" : "Hjólabretti",
     "Wine tasting" : "Vínsmökkun",
     "Golf" : "Golf",
     "Dinner" : "Kvöldverður",
-    "Lunch" : "Hádegisverður"
+    "Lunch" : "Hádegisverður",
+    "User not found" : "Notandi fannst ekki"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
