@@ -12,6 +12,10 @@ OC.L10N.register(
     "Cheers!" : "それでは！",
     "Upcoming events" : "今後のイベント",
     "Appointments" : "予定",
+    "Schedule an appointment" : "予定を入れる",
+    "Dear %s, please confirm your booking" : "%s様、予定を承認してください。",
+    "Confirm" : "承認",
+    "This confirmation link expires in %s hours." : "承認用リンクの有効期限は1%s時間です。",
     "Appointment:" : "予定：",
     "Date:" : "日時:",
     "Where:" : "場所:",
@@ -24,6 +28,7 @@ OC.L10N.register(
     "Next day" : "翌日",
     "Next week" : "翌週",
     "Next month" : "翌月",
+    "New event" : "新しいイベント",
     "Today" : "今日",
     "Day" : "日",
     "Week" : "週",
@@ -33,13 +38,18 @@ OC.L10N.register(
     "Copy link" : "リンクをコピー",
     "Edit" : "編集",
     "Delete" : "削除",
+    "Appointment link was copied to clipboard" : "予定リンクがクリップボードにコピーされました",
+    "Appointment link could not be copied to clipboard" : "予定リンクをクリップボードにコピーできませんでした",
     "Add new" : "新規作成",
     "Untitled calendar" : "無題のカレンダー",
+    "Disable calendar" : "カレンダーを無効にする",
+    "Enable calendar" : "カレンダーを有効にする",
     "Edit name" : "名前を編集",
     "Saving name …" : "名前を保存しています …",
     "Edit color" : "色を編集",
     "Saving color …" : "色を保存しています …",
     "Copy private link" : "プライベートリンクをコピー",
+    "Export" : "エクスポート",
     "Unshare from me" : "共有を自分から解除",
     "An error occurred, unable to change visibility of the calendar." : "エラーが発生したため、カレンダーの表示状態を変更できません。",
     "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
@@ -79,6 +89,7 @@ OC.L10N.register(
     "An error occurred, unable to change the permission of the share." : "エラーが発生したため、共有の権限を変更できませんでした。",
     "+ New calendar" : "+ 新しいカレンダー",
     "New calendar" : "新しいカレンダー",
+    "Name for new calendar" : "新しいカレンダーの名前",
     "Creating calendar …" : "カレンダーを作成中 …",
     "New calendar with task list" : "タスクリスト付きの新しいカレンダー",
     "New subscription from link (read-only)" : "リンクからの新規加入 (読み取り専用)",
@@ -92,6 +103,9 @@ OC.L10N.register(
     "Restore" : "復元",
     "Delete permanently" : "完全に削除する",
     "Empty trash bin" : "ゴミ箱を空にする",
+    "Unknown calendar" : "不明なカレンダー",
+    "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
+    "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
     "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
     "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["ゴミ箱にある項目は {numDays} 日後に削除されます"],
     "Could not update calendar order." : "カレンダーの順番を更新できません。",
@@ -136,9 +150,16 @@ OC.L10N.register(
     "No reminder" : "リマインダーなし",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
+    "Appointment was created successfully" : "予定の作成に成功しました。",
+    "Appointment was updated successfully" : "予定は正常に更新されました。",
     "0 minutes" : "0分",
+    "To configure appointments, add your email address in personal settings." : "予定を設定するには、個人設定であなたのメールアドレスを追加してください。",
     "Location" : "場所",
     "Description" : "説明",
+    "Visibility" : "公開レベル",
+    "Duration" : "期間",
+    "to" : "宛先",
+    "Delete slot" : "スロットを削除",
     "Add" : "追加",
     "Monday" : "月曜日",
     "Tuesday" : "火曜日",
@@ -172,18 +193,18 @@ OC.L10N.register(
     "_hour_::_hours_" : ["時間"],
     "_day_::_days_" : ["日"],
     "_week_::_weeks_" : ["週"],
-    "Available." : "利用可能",
-    "Not available." : "利用できません",
-    "Invitation accepted." : "招待を受け付けました",
-    "Invitation declined." : "招待は辞退しました",
-    "Invitation sent." : "招待が送信されました",
+    "Available" : "利用可能",
+    "Not available" : "利用できません",
     "Free" : "空き",
     "Busy (tentative)" : "ビジー (暫定)",
     "Busy" : "ビジー",
     "Out of office" : "オフィス外",
     "Unknown" : "不明",
+    "Accept" : "承諾",
+    "Decline" : "拒否",
     "Tentative" : "暫定的",
     "Create Talk room for this event" : "このイベントに通話ルームを作成する",
+    "Show busy times" : "忙しい時間を表示",
     "No attendees yet" : "出席者はまだいません",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "Send email" : "メールを送信",
@@ -220,6 +241,8 @@ OC.L10N.register(
     "weekday" : "平日",
     "weekend day" : "週末",
     "Whiteboard" : "ホワイトボード",
+    "available" : "利用可能",
+    "unavailable" : "利用不可",
     "More" : "もっと見る",
     "Update this and all future" : "これ以降を更新",
     "Public calendar does not exist" : "公開カレンダーは存在しません",
@@ -237,6 +260,8 @@ OC.L10N.register(
     "Type to search time zone" : "入力して時間帯を検索",
     "Global" : "グローバル",
     "Select date" : "日付を選択",
+    "Appointment Details:" : "予定の詳細：",
+    "Time:" : "時刻:",
     "Personal" : "個人",
     "No more events today" : "今日はこれ以上イベントがありません",
     "No upcoming events" : "今後のイベントはありません",
@@ -249,9 +274,9 @@ OC.L10N.register(
     "Delete this occurrence" : "この出来事を削除",
     "Details" : "詳細",
     "Attendees" : "参加者",
+    "Resources" : "リソース",
     "Close" : "閉じる",
     "Show more details" : "詳細を見る",
-    "Download {name}" : "{name}をダウンロード",
     "Anniversary" : "記念日",
     "Appointment" : "アポイントメント",
     "Business" : "ビジネス",
@@ -286,12 +311,15 @@ OC.L10N.register(
     "Untitled event" : "無題のイベント",
     "Untitled task" : "タイトルなしタスク",
     "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
+    "Prev" : "前へ",
+    "Next" : "次へ",
     "Prev year" : "去年",
     "Next year" : "来年",
     "Year" : "年",
     "W" : "W",
     "No events to display" : "表示するイベントはありません",
     "No events" : "イベントはありません",
+    "Other" : "その他",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
@@ -309,6 +337,7 @@ OC.L10N.register(
     "Meditation" : "座禅",
     "Relaxing" : "休暇",
     "Relax" : "休み",
+    "Commuting" : "通勤中",
     "Finance" : "金融",
     "Bank" : "銀行",
     "Money" : "お金",
@@ -317,6 +346,8 @@ OC.L10N.register(
     "Concert" : "演奏会",
     "Festival" : "祭",
     "Presentation" : "プレゼンテーション",
+    "Talk" : "トーク",
+    "Deadline" : "期限",
     "Camping" : "キャンプ場",
     "Camp" : "キャンプ",
     "Election" : "選挙",
