@@ -6,53 +6,85 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "გვსურს შეგატყობინოთ, რომ %s მომხმარებელმა გამოაქყვენა კალენდარი »%s«.",
     "Open »%s«" : "გახნსნა »%s«",
     "Cheers!" : "წარმატებები!",
+    "Confirm" : "დადასტურება",
+    "Where:" : "სად:",
+    "Description:" : "აღწერა:",
     "Calendar" : "კალენდარი",
+    "New event" : "ახალი მოვლენა",
     "Today" : "დღეს",
     "Day" : "დღე",
     "Week" : "კვირა",
     "Month" : "თვე",
     "List" : "ჩამონათვალი",
+    "Preview" : "წინასწარი ჩვენება",
+    "Copy link" : "ბმულის კოპირება",
+    "Edit" : "შეცვლა",
     "Delete" : "წაშლა",
+    "Export" : "ექსპორტი",
     "Share link" : "ბმულის გაზიარება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეგიძლია შეცვლა",
     "New calendar" : "ახალი კალენდარი",
+    "Name" : "სახელი",
+    "Deleted" : "გაუქმდა",
+    "Restore" : "აღდგენა",
+    "Delete permanently" : "სამუდამოდ წაშლა",
     "Filename" : "ფაილის სახელი",
     "Cancel" : "უარყოფა",
     "Automatic" : "ავტომატური",
     "or" : "ან",
+    "List view" : "ჩამონათვლისებური ხედი",
     "Actions" : "მოქმედებები",
     "Show week numbers" : "კვირის ნომრების ჩვენება",
     "Settings & import" : "პარამეტრები და იმპორტი",
     "Location" : "ადგილმდებარეობა",
     "Description" : "აღწერილობა",
+    "to" : "ვის",
+    "Add" : "დამატება",
     "Monday" : "ორშაბათი",
+    "Tuesday" : "სამშაბათი",
+    "Wednesday" : "ოთხშაბათი",
+    "Thursday" : "ხუთშაბათი",
+    "Friday" : "პარასკევი",
+    "Saturday" : "შაბათი",
+    "Sunday" : "კვირა",
     "Save" : "შენახვა",
     "Update" : "განახლება",
+    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "Notification" : "შეტყობინება",
     "Email" : "ელ-ფოსტა",
     "Unknown" : "ამოუცნობი",
+    "Accept" : "მიღება",
+    "Decline" : "ურაყოფა",
     "Tentative" : "საცდელი",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "All day" : "მთელი დღე",
     "Repeat" : "გამეორება",
     "never" : "არასდროს",
     "after" : "შემდეგ",
+    "available" : "ხელმისაწვდომი",
     "More" : "უფრო მეტი",
     "Global" : "გლობალური",
     "Personal" : "პირადი",
     "Details" : "დეტლაები",
     "Attendees" : "დამსწრეები",
+    "Resources" : "რესურსები",
     "Close" : "დახურვა",
     "Anniversary" : "დაბადების დღე",
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
     "Daily" : "ყოველდღიური",
     "Weekly" : "ყოველკვირეული",
+    "Prev" : "წინა",
+    "Next" : "შემდეგი",
+    "Other" : "სხვა",
     "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
     "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
     "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
     "Status" : "სტატუსი",
     "Confirmed" : "დადასტურებლია",
     "Categories" : "კატეგორიები",
-    "Mail" : "ფოსტა"
+    "Talk" : "საუბარი",
+    "Mail" : "ფოსტა",
+    "Birthday" : "დაბადების დრე"
 },
 "nplurals=2; plural=(n!=1);");
