@@ -6,26 +6,42 @@ OC.L10N.register(
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
-    "Download" : "Muat turun",
+    "Edit" : "Sunting",
     "Delete" : "Padam",
+    "Export" : "Eksport",
     "Share link" : "Share link",
     "can edit" : "boleh mengubah",
     "New calendar" : "Kalendar baru",
+    "Name" : "Nama",
+    "Deleted" : "Dipadam",
+    "Restore" : "Pulihkan",
     "Cancel" : "Batal",
+    "Location" : "Lokasi",
+    "Description" : "Keterangan",
+    "to" : "kepada",
+    "Add" : "Tambah",
+    "Monday" : "Isnin",
+    "Tuesday" : "Selasa",
+    "Wednesday" : "Rabu",
+    "Thursday" : "Khamis",
+    "Friday" : "Jumaat",
+    "Saturday" : "Sabtu",
+    "Sunday" : "Ahad",
+    "Save" : "Simpan",
+    "Update" : "Kemaskini",
+    "Your email address" : "Alamat emel anda",
     "Email" : "Email",
     "Repeat" : "Ulang",
-    "Save" : "Simpan",
     "never" : "jangan",
-    "Monday" : "Isnin",
     "More" : "Lanjutan",
-    "Update" : "Kemaskini",
     "Personal" : "Peribadi",
     "Attendees" : "Jemputan",
     "Close" : "Tutup",
     "Daily" : "Setiap hari",
     "Weekly" : "Setiap minggu",
-    "Location" : "Lokasi",
-    "Description" : "Keterangan",
-    "Mail" : "Mel"
+    "Next" : "Seterus",
+    "Other" : "Lain",
+    "Mail" : "Mel",
+    "Birthday" : "Hari lahir"
 },
 "nplurals=1; plural=0;");
