@@ -8,6 +8,11 @@ OC.L10N.register(
     "Open »%s«" : "Åpne \"%s\"",
     "Cheers!" : "Ha det!",
     "Upcoming events" : "Kommende hendelser",
+    "Appointments" : "Avtaler",
+    "Confirm" : "Bekreft",
+    "Date:" : "Dato:",
+    "Where:" : "Hvor:",
+    "Description:" : "Beskrivelse:",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
     "Previous day" : "Forrige dag",
@@ -16,11 +21,15 @@ OC.L10N.register(
     "Next day" : "Neste dag",
     "Next week" : "Neste uke",
     "Next month" : "Neste måned",
+    "New event" : "Ny hendelse",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Uke",
     "Month" : "Måned",
     "List" : "Liste",
+    "Preview" : "Forhåndsvis",
+    "Copy link" : "Kopier lenke",
+    "Edit" : "Rediger",
     "Delete" : "Slett",
     "Untitled calendar" : "Kalender uten tittel",
     "Edit name" : "Rediger navn",
@@ -28,6 +37,7 @@ OC.L10N.register(
     "Edit color" : "Rediger farge",
     "Saving color …" : "Lagrer farge  ...",
     "Copy private link" : "Kopier privat lenke",
+    "Export" : "Eksporter",
     "Unshare from me" : "Fjern deling fra meg",
     "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
     "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
@@ -73,6 +83,12 @@ OC.L10N.register(
     "Creating subscription …" : "Oppretter abonnement ...",
     "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
+    "Trash bin" : "Papirkurv",
+    "Name" : "Navn",
+    "Deleted" : "Slettet",
+    "Restore" : "Gjenoprett",
+    "Delete permanently" : "Slett permament",
+    "Empty trash bin" : "Tøm papirkurv",
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendrene.",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
@@ -96,6 +112,7 @@ OC.L10N.register(
     "Day view" : "Dagsvisning",
     "Week view" : "Ukesvisning",
     "Month view" : "Månedsvisning",
+    "List view" : "Listevisning",
     "Actions" : "Handlinger",
     "Create event" : "Opprettet hendelse",
     "Show shortcuts" : "Vis snarveier",
@@ -113,9 +130,19 @@ OC.L10N.register(
     "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
     "Location" : "Sted",
     "Description" : "Beskrivelse",
+    "Duration" : "Varighet",
+    "to" : "til",
+    "Add" : "Legg til",
     "Monday" : "Mandag",
+    "Tuesday" : "Tirsdag",
+    "Wednesday" : "Onsdag",
+    "Thursday" : "Torsdag",
+    "Friday" : "Fredag",
+    "Saturday" : "Lørdag",
+    "Sunday" : "Søndag",
     "Save" : "Lagre",
     "Update" : "Oppdater",
+    "Your email address" : "Din e-postadresse",
     "before at" : "før ved",
     "Notification" : "Varsel",
     "Email" : "E-post",
@@ -129,23 +156,28 @@ OC.L10N.register(
     "on" : "på",
     "at" : "på",
     "+ Add reminder" : "+Legg til påminnelse",
+    "Add reminder" : "Legg til påminnelse",
     "_second_::_seconds_" : ["sekund","sekunder"],
     "_minute_::_minutes_" : ["minutt","minutter"],
     "_hour_::_hours_" : ["time","timer"],
     "_day_::_days_" : ["dag","dager"],
     "_week_::_weeks_" : ["uke","uker"],
+    "Available" : "Tilgjengelig",
     "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
     "Free" : "Ledig",
     "Busy (tentative)" : "Opptatt (foreløpig)",
     "Busy" : "Opptatt",
     "Out of office" : "Fraværende",
     "Unknown" : "Ukjent",
+    "Accept" : "Aksepter",
+    "Decline" : "Avslå",
     "Tentative" : "Foreløpig",
     "Create Talk room for this event" : "Opprett Talk-rom for denne hendelsen",
     "Show busy times" : "Vis opptatte tider",
     "No attendees yet" : "Ingen deltagere enda",
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
+    "Send email" : "Send e-post",
     "Chairperson" : "Ordstyrer",
     "Required participant" : "Påkrevd deltaker",
     "Optional participant" : "Ønsket deltaker",
@@ -177,6 +209,7 @@ OC.L10N.register(
     "_year_::_years_" : ["år","år"],
     "weekday" : "ukedag",
     "weekend day" : "helg",
+    "available" : "tilgjengelig",
     "More" : "Mer",
     "Update this occurrence" : "Oppdater denne hendelsen",
     "Update this and all future" : "Oppdater denne og fremtidige hendelser",
@@ -194,6 +227,7 @@ OC.L10N.register(
     "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
     "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og tidspunkt",
     "Global" : "Global",
+    "Time:" : "Tid:",
     "Personal" : "Personlig",
     "No more events today" : "Ingen flere hendelser i dag",
     "Event does not exist" : "Avtalen finnes ikke",
@@ -201,10 +235,10 @@ OC.L10N.register(
     "Delete this and all future" : "Slett denne og fremtidige hendelser",
     "Details" : "Detaljer",
     "Attendees" : "Deltakere",
+    "Resources" : "Ressurser",
     "Close" : "Lukk",
     "Show more details" : "Vis flere detaljer",
     "Subscribe to {name}" : "Abonner på {name}",
-    "Download {name}" : "Last ned {name}",
     "Anniversary" : "Jubileum",
     "Appointment" : "Avtale",
     "Business" : "Forretninger",
@@ -227,7 +261,11 @@ OC.L10N.register(
     "Yearly" : "Årlig",
     "Untitled event" : "Hendelse uten tittel",
     "Untitled task" : "Oppgave uten tittel",
+    "Prev" : "Forrige",
+    "Next" : "Neste",
+    "Year" : "År",
     "No events" : "Ingen hendelser",
+    "Other" : "Annet",
     "When shared show" : "Når delt vis",
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
@@ -247,7 +285,9 @@ OC.L10N.register(
     "Imported {filename}" : "Importerte {filename}",
     "Meditation" : "Meditasjon",
     "Relaxing" : "Avslapping",
+    "Commuting" : "Pendler",
     "Presentation" : "Presentasjon",
+    "Talk" : "Samtale",
     "Camping" : "Camping",
     "Movie" : "Film",
     "Cinema" : "Kino",
@@ -275,6 +315,7 @@ OC.L10N.register(
     "Doctor" : "Doktor",
     "Health" : "Helse",
     "Dentist" : "Tannlege",
+    "Hospital" : "Sykehus",
     "Interview" : "Intervju",
     "Training" : "Trene",
     "Practice" : "Øve",
@@ -309,12 +350,14 @@ OC.L10N.register(
     "Party" : "Fest",
     "Celebration" : "Feiring",
     "Celebrate" : "Feire",
+    "Birthday" : "Fødselsdag",
     "Shopping" : "Shoppe",
     "Skate" : "Skate",
     "Skateboard" : "Skatebrett",
     "Wine tasting" : "Vinsmaking",
     "Golf" : "Golf",
     "Dinner" : "Middag",
-    "Lunch" : "Lunsj"
+    "Lunch" : "Lunsj",
+    "User not found" : "Fant ikke brukeren"
 },
 "nplurals=2; plural=(n != 1);");
