@@ -5,6 +5,9 @@ OC.L10N.register(
     "Open »%s«" : "Dobrir « %s »",
     "Cheers!" : "A lèu !",
     "Upcoming events" : "Eveniments venents",
+    "Confirm" : "Confirmar",
+    "Date:" : "Data :",
+    "Where:" : "Ont :",
     "Description:" : "Descripcion :",
     "Calendar" : "Calendièr",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
@@ -20,6 +23,7 @@ OC.L10N.register(
     "Month" : "Mes",
     "List" : "Tièra",
     "Preview" : "Apercebut",
+    "Copy link" : "Copiar lo ligam",
     "Edit" : "Modificar",
     "Delete" : "Suprimir",
     "Untitled calendar" : "Calendièr sens nom",
@@ -28,6 +32,7 @@ OC.L10N.register(
     "Edit color" : "Modificar la color",
     "Saving color …" : "Enregistrament de la color …",
     "Copy private link" : "Copiar lo ligam privat",
+    "Export" : "Exportar",
     "Share link" : "Partejar lo ligam",
     "Publish calendar" : "Publicar lo calendièr",
     "Copy public link" : "Copiar lo ligam public",
@@ -37,6 +42,10 @@ OC.L10N.register(
     "can edit" : "pòt modificar",
     "+ New calendar" : "+ Calendièr novèl",
     "New calendar" : "Calendièr novèl",
+    "Name" : "Nom",
+    "Deleted" : "Suprimit",
+    "Restore" : "Restaurar",
+    "Delete permanently" : "Suprimir definitivament",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
@@ -55,6 +64,8 @@ OC.L10N.register(
     "Description" : "Descripcion",
     "Visibility" : "Visibilitat",
     "Duration" : "Durada",
+    "to" : "a",
+    "Add" : "Apondre",
     "Monday" : "diluns",
     "Tuesday" : "Dimars",
     "Wednesday" : "Dimècres",
@@ -65,6 +76,7 @@ OC.L10N.register(
     "Save" : "Salvar",
     "Update" : "Metre a jorn",
     "Your name" : "Vòstre nom",
+    "Your email address" : "Vòstra adreça electronica",
     "Reminder" : "Recòrd",
     "Notification" : "Notificacion",
     "Email" : "Adreça corrièl",
@@ -80,10 +92,12 @@ OC.L10N.register(
     "_hour_::_hours_" : ["ora","oras"],
     "_day_::_days_" : ["jorn","jorns"],
     "_week_::_weeks_" : ["setmana","setmanas"],
-    "Suggested." : "Suggerit.",
+    "Available" : "Disponible",
     "Busy" : "Ocupat",
     "Unknown" : "Desconegut",
+    "Accept" : "Acceptar",
     "Tentative" : "Provisòri",
+    "Send email" : "Enviar email",
     "All day" : "Tota la jornada",
     "Repeat" : "Repetir",
     "never" : "pas jamai",
@@ -113,7 +127,6 @@ OC.L10N.register(
     "Details" : "Detalhs",
     "Attendees" : "Convidats",
     "Close" : "Tampar",
-    "Download {name}" : "Telecargar {name}",
     "Anniversary" : "Anniversari",
     "Appointment" : "Rendetz-vos",
     "Business" : "Afar",
@@ -133,6 +146,9 @@ OC.L10N.register(
     "_%n time_::_%n times_" : ["%n còp","%n còps"],
     "Untitled event" : "Eveniment sens nom",
     "Untitled task" : "Prètzfach sens nom",
+    "Next" : "Seguent",
+    "Year" : "Annada",
+    "Other" : "Autre",
     "Add a location" : "Apondre un lòc",
     "Add a description" : "Apondre una descripcion",
     "Status" : "Estat",
@@ -140,7 +156,9 @@ OC.L10N.register(
     "Canceled" : "Anullat",
     "Categories" : "Categorias",
     "Custom color" : "Color personalizada",
+    "Commuting" : "En comunicacion",
     "Presentation" : "Presentacion",
+    "Talk" : "Talk",
     "Movie" : "Film",
     "Cinema" : "Cinèma",
     "Mail" : "Mail",
@@ -163,6 +181,8 @@ OC.L10N.register(
     "Pizza" : "Pizza",
     "Travelling" : "Viatge",
     "Party" : "Fèsta",
-    "Shopping" : "Crompas"
+    "Birthday" : "Data de naissença",
+    "Shopping" : "Crompas",
+    "User not found" : "Utilizaire pas trobat"
 },
 "nplurals=2; plural=(n > 1);");
