@@ -6,46 +6,76 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
     "Open »%s«" : "Hap »%s«",
     "Cheers!" : "Gëzuar!",
+    "Confirm" : "Konfirmo",
+    "Where:" : "Ku:",
+    "Description:" : "Përshkrimi:",
     "Calendar" : "Kalendar",
+    "New event" : "Veprimtari e re",
     "Today" : "Sot",
     "Day" : "Ditë",
     "Week" : "Javë",
     "Month" : "Muaj",
     "List" : "List",
+    "Preview" : "Parapamje ",
+    "Copy link" : "Kopjo linkun",
+    "Edit" : "Përpuno",
     "Delete" : "Fshije",
+    "Export" : "Eksport",
     "Share link" : "Ndani lidhjen",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
     "can edit" : "mund të përpunojnë",
     "New calendar" : "Kalendar i ri",
+    "Name" : "Emri",
+    "Deleted" : "E fshirë",
+    "Restore" : "Rikthe",
+    "Delete permanently" : "Fshije përgjithmonë",
     "Filename" : "Emri i skedarit",
     "Cancel" : "Anuloje",
     "Automatic" : "Automatike",
+    "List view" : "Pamje listë",
     "Actions" : "Veprimet",
     "Show week numbers" : "Shfaq numra javësh",
     "Settings & import" : "Konfigurimet dhe importi",
     "Location" : "Vendndodhje",
     "Description" : "Përshkrim",
+    "to" : "te",
+    "Add" : "Shto",
     "Monday" : "E hënë",
+    "Tuesday" : "E martë",
+    "Wednesday" : "E mërkurë",
+    "Thursday" : "E enjte",
+    "Friday" : "E premte",
+    "Saturday" : "E shtunë",
+    "Sunday" : "E dielë",
     "Save" : "Ruaj",
     "Update" : "Përditësoje",
+    "Your email address" : "Adresa juaj email",
     "Notification" : "Njoftim",
     "Email" : "Emaili",
     "Unknown" : "I/E panjohur",
+    "Accept" : "Prano",
+    "Decline" : "Refuzo",
     "Tentative" : "Tentativë",
+    "Send email" : "Dërgo email",
     "All day" : "Gjithë ditën",
     "Repeat" : "Përsërite",
     "never" : "kurrë",
     "after" : "pas",
+    "available" : "në gjëndje",
     "More" : "Më tepër",
     "Global" : "Globale",
     "Personal" : "Personale",
     "Details" : "Detajet",
     "Attendees" : "Pjesëmarrës",
+    "Resources" : "Burimet",
     "Close" : "Mbylle",
     "Anniversary" : "Përvjetor",
     "Week {number} of {year}" : "Java e {number} e {year}",
     "Daily" : "Përditë",
     "Weekly" : "Çdo javë",
+    "Prev" : "I mëparshëm",
+    "Next" : "Tjetër",
+    "Other" : "Tjetër",
     "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
     "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
     "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
@@ -54,6 +84,7 @@ OC.L10N.register(
     "Categories" : "Kategoritë",
     "Presentation" : "Paraqitje",
     "Office" : "Zyrë",
-    "Mail" : "Posta"
+    "Mail" : "Posta",
+    "Birthday" : "Datëlindje"
 },
 "nplurals=2; plural=(n != 1);");
