@@ -3,24 +3,38 @@ OC.L10N.register(
     {
     "Cheers!" : "U zdravlje!",
     "Today" : "Today",
-    "Download" : "Preuzmi",
+    "Preview" : "Pregled",
+    "Copy link" : "Kopiraj vezu",
+    "Edit" : "Izmeni",
     "Delete" : "Delete",
     "Share link" : "Veza deljenja",
     "can edit" : "može da menja",
+    "Name" : "Ime",
+    "Deleted" : "Obrisano",
+    "Delete permanently" : "Obriši zauvek",
     "Filename" : "Ime fajla",
     "Cancel" : "Cancel",
+    "List view" : "Prikaz liste",
+    "Description" : "Opis",
+    "Add" : "Dodaj",
+    "Monday" : "Ponedeljak",
+    "Tuesday" : "Utorak",
+    "Wednesday" : "Sreda",
+    "Thursday" : "Četvrtak",
+    "Friday" : "Petak",
+    "Saturday" : "Subota",
+    "Sunday" : "Nedelja",
+    "Save" : "Save",
+    "Update" : "Ažuriraj",
     "Email" : "email",
     "Unknown" : "Nepoznato",
     "never" : "never",
-    "Monday" : "Ponedeljak",
     "More" : "More",
-    "Save" : "Save",
-    "Update" : "Ažuriraj",
     "Details" : "Detalji",
     "Close" : "Zatvori",
     "Daily" : "дневно",
     "Weekly" : "недељно",
-    "Description" : "Opis",
+    "Other" : "Ostali",
     "Movie" : "Film",
     "Mail" : "Pošta"
 },
