@@ -8,31 +8,57 @@ OC.L10N.register(
     "Hello," : "สวัสดี",
     "Open »%s«" : "เปิด »%s«",
     "Cheers!" : "ไชโย!",
+    "Confirm" : "ยืนยัน",
     "Calendar" : "ปฏิทิน",
+    "New event" : "เหตุการณ์ใหม่",
     "Today" : "วันนี้",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
     "Month" : "เดือน",
+    "Preview" : "ตัวอย่าง",
+    "Copy link" : "คัดลอกลิงก์",
+    "Edit" : "แก้ไข",
     "Delete" : "ลบ",
+    "Export" : "ส่งออก",
     "Share link" : "แชร์ลิงค์",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
     "can edit" : "สามารถแก้ไข",
     "New calendar" : "สร้างปฏิทินใหม่",
+    "Name" : "ชื่อ",
+    "Deleted" : "ลบแล้ว",
+    "Restore" : "คืนค่า",
+    "Delete permanently" : "ลบแบบถาวร",
+    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
+    "Filename" : "ชื่อไฟล์",
     "Cancel" : "ยกเลิก",
     "Automatic" : "อัตโนมัติ",
+    "List view" : "มุมมองแบบรายการ",
     "Actions" : "การกระทำ",
     "Location" : "ตำแหน่งที่อยู่",
     "Description" : "รายละเอียด",
+    "to" : "ถึง",
+    "Add" : "เพิ่ม",
     "Monday" : "วันจันทร์",
+    "Tuesday" : "วันอังคาร",
+    "Wednesday" : "วันพุธ",
+    "Thursday" : "วันพฤหัสบดี",
+    "Friday" : "วันศุกร์",
+    "Saturday" : "วันเสาร์",
+    "Sunday" : "วันอาทิตย์",
     "Save" : "บันทึก",
     "Update" : "อัพเดท",
+    "Your email address" : "ที่อยู่อีเมลของคุณ",
     "Email" : "อีเมล",
     "Unknown" : "ไม่ทราบ",
+    "Accept" : "ยอมรับ",
+    "Decline" : "ลดลง",
     "Tentative" : "ชั่วคราว",
+    "Send email" : "ส่งอีเมล",
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
     "after" : "หลัง",
     "More" : "เพิ่มเติม",
+    "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
     "Personal" : "ส่วนตัว",
     "Details" : "รายละเอียด",
@@ -42,12 +68,17 @@ OC.L10N.register(
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รุ่นรายวัน",
     "Weekly" : "รายสัปดาห์",
+    "Next" : "ถัดไป",
+    "Other" : "อื่น ๆ",
     "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
+    "Status" : "สถานะ",
     "Confirmed" : "ได้รับการยืนยันแล้ว",
+    "Commuting" : "กำลังเดินทาง",
     "Presentation" : "งานนำเสนอ",
     "Office" : "สำนักงาน",
-    "Mail" : "จดหมาย"
+    "Mail" : "จดหมาย",
+    "Birthday" : "วันเกิด"
 },
 "nplurals=1; plural=0;");
